get_canonical_type_def

Function get_canonical_type_def 

fn get_canonical_type_def<FEN: FoundryEvmNetwork>(
    name_or_def: &String,
    state: &mut Cheatcodes<FEN>,
    path: Option<PathBuf>,
) -> Result<String>
Returns EIP-712 canonical type definition from the provided string type representation or type name. If type name provided, then it looks up bindings from file generated by forge bind-json.