fn get_type_def_from_bindings(
name: &String,
path: PathBuf,
root: &PathBuf,
) -> Result<String>Expand description
Returns the EIP-712 type definition from the bindings in the provided path. Assumes that read validation for the path has already been checked.